@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of the python-chess library.
-# Copyright (C) 2012-2017 Niklas Fiekas <niklas.fiekas@backscattering.de>
+# Copyright (C) 2012-2018 Niklas Fiekas <niklas.fiekas@backscattering.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -608,7 +608,7 @@ class Table(object):
                 self.enc_type = 2
             else:  # only for suicide
                 j = 16
-                for i in range(16):
+                for _ in range(16):
                     for piece_type in PCHR:
                         if 1 < black_part.count(piece_type) < j:
                             j = black_part.count(piece_type)
@@ -1574,7 +1574,7 @@ class Tablebases(object):
         for move in board.generate_legal_moves(to_mask=board.occupied_co[not board.turn]):
             board.push(move)
             try:
-                v_plus, success = self.probe_ab(board, -beta, -alpha)
+                v_plus, _ = self.probe_ab(board, -beta, -alpha)
                 v = -v_plus
             finally:
                 board.pop()
@@ -1631,7 +1631,7 @@ class Tablebases(object):
 
             board.push(move)
             try:
-                v_plus, success = self.sprobe_ab(board, -beta, -alpha)
+                v_plus, _ = self.sprobe_ab(board, -beta, -alpha)
                 v = -v_plus
             finally:
                 board.pop()
@@ -1680,7 +1680,7 @@ class Tablebases(object):
             raise KeyError("syzygy tables support up to 6 pieces, not {0}: {1}".format(chess.popcount(board.occupied), board.fen()))
 
         # Probe.
-        v, success = self.probe_ab(board, -2, 2)
+        v, _ = self.probe_ab(board, -2, 2)
 
         # If en passant is not possible, we are done.
         if not board.ep_square or self.variant.captures_compulsory:
@@ -1693,7 +1693,7 @@ class Tablebases(object):
         for move in board.generate_legal_ep():
             board.push(move)
             try:
-                v0_plus, success = self.probe_ab(board, -2, 2)
+                v0_plus, _ = self.probe_ab(board, -2, 2)
                 v0 = -v0_plus
             finally:
                 board.pop()
@@ -1812,7 +1812,7 @@ class Tablebases(object):
         +-----+------------------+--------------------------------------------+
         | WDL | DTZ              |                                            |
         +=====+==================+============================================+
-        |  -2 | -100 <= n < -1   | Unconditional loss (assuming 50-move       |
+        |  -2 | -100 <= n <= -1  | Unconditional loss (assuming 50-move       |
         |     |                  | counter is zero), where a zeroing move can |
         |     |                  | be forced in -n plies.                     |
         +-----+------------------+--------------------------------------------+
@@ -1828,7 +1828,7 @@ class Tablebases(object):
         |     |                  | n - 100 plies (if a later phase is         |
         |     |                  | responsible for the cursed win).           |
         +-----+------------------+--------------------------------------------+
-        |   2 |     1 < n <= 100 | Unconditional win (assuming 50-move        |
+        |   2 |    1 <= n <= 100 | Unconditional win (assuming 50-move        |
         |     |                  | counter is zero), where a zeroing move can |
         |     |                  | be forced in n plies.                      |
         +-----+------------------+--------------------------------------------+
@@ -1872,7 +1872,7 @@ class Tablebases(object):
         for move in board.generate_legal_ep():
             board.push(move)
             try:
-                v0_plus, success = self.probe_ab(board, -2, 2)
+                v0_plus, _ = self.probe_ab(board, -2, 2)
                 v0 = -v0_plus
             finally:
                 board.pop()
